==> linuxconf-1.33r6.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/mailconf-msg-1.33r6.cs <==
g  mailconf                 $  2  F  L  _  r               @                %  C  Z  j              	  	>  	M  	Z  	i  	  	  	  	  	  	  
  
1  
C  
P  
Y  
s  
  
  
  
  
               +  3  C  O  m        
  
  
  7  A  O          
  U  v          ,  L  ~        0  d  s          9  R    (  A  ]  w    R  i      +  =  \            
  )  4  R  }      	    _  p            6  H  p              <  ]  s          
  -  J  a  |            4  F  ^              J  k  z        A  S  e  n  ~                            )   <   O   v           !.  !F  !  !  !  !  "   "  "  "  #9  #T  #]  #v  #  #  #  $2  $Q  $j  $x  $  $  $  %  %;  %V  %z  %  %  %  &)  &/  &6  &U  &\  &  &  &  '!  '7  '  (  (  (E  (L  (a  (p  (w  (  (  (  (  (  )!  ),  )  )  )  *  *  *  **  *6  *R  *[  *d  *s  *  *  *  *  +  +E  +L  +y  +  +  +  +  ,  ,  ,)  ,0  ,V  ,`  ,{  ,  ,  ,  ,  ,  ,  -  -!  -*  -A  -J  -g  -  -  -  -  -  -  -  .
  ..  .Y  .  .  .  .  .  /  /  /d  /w  /  /  /  /  /  0  0  03  0I  0O  0f  0  0  0  0  0  1  1(  1V  2  2O  2_  2  2  2  2  2  3!  3B  3s  3  3  3  4  4  5-  5|  5  5  5  6  6  6,  6H  6R  6`  7  7$  7:  7l  7  7  7  7  8  85  8F  8S  8  8  8  8  8  8  8  8  9  9:  9a  9j  9n%s neexistuje %s nen spustiteln alias Filtrovac program Soubor se seznamem Definice jednoho aliasu Pomoc [Pidej] lze zskat msto pro dal
mailing list
 prava aliasu Nutno zadat jmno Vechny poloky jsou przdn Duplikace aliasu, odmtnuto prava globlnch alias pro e-mail Zde lze upravovat/pidvat/mazat
aliasy pro e-mail, kter palt pro cel systm Pomoc [Add] lze pidato nov alias Zpis %s Aliasy pro domny Aliasy pro tento pota Prezentovat tento pota jako E-mail server E-mailov brna Protokol pro e-mailovou brnu Vylepen SMTP (ESMTP) Standardn SMTP Doporuen modern UUCP Star UUCP Vlastnosti UUCP mail nespracovvt v dvkch Omezen velikosti zprvy Doruovat lokln pro uivatele Nepouvat makardu pro uivatele Formt databze pro speciln smrovn Vlastnosti DNS ekat na DNS Nepouvat DNS Omezit DNS len na domny Zkladn nastaven sendmailu Nastavit sendmail %s byl pegenerovn! Zkladn informace Speciln smrovn (pro domny) Komplexn smrovn (pro uivatele) Uivatelsk aliasy Testovac ppady Konfigurovat Nastavit Konfigurtor pro sendmail Tato obrazovka umouje konfigurovat
Sendmail, program pro penos elektronick poty
 Cl Pesmrovn Spravovat subdomny stejn Program pro posln Speciln smrovn Vlote clov pota, pota
pes kter se m pota pesmrovat
a program, kter zajist penos (mailer) Nutno vyplnit vechny poloky Seeciln smrovn Zde lze upravovat/pidvat/mazat smrovn
 Pomoc [Pidej] lze pidat specifikaci jednoho smrovn Odeslatel Adrest Nov odeslatel Pepsno na Pesmrovat na server (nepov) Pomoc [Sma] lze smazat tento zznam Nov komplexn smrovn Komplexn smrovn pro %s Zde lze nastavit zachytvn e-mail
a jejich pesmrovn na jin e-mailov server,
ppadn za pouit jinho protokolu.
Je mon pepisovat adresu adresta,
ppadn i odeslatele
 Pomoc [Pidej] lze pidat pravidlo pro komplexn smrovn Komplexn smrovn Zde lze nastavit rzn komplexn smrovn e-mail
Klem je clov adresa, vetn uivatelskho jmna
 Generovat Generovn %s Zmnilo se nastaven sendmailu.
Mus bt vygenerovn nov soubor %s.
M se tak stt okamit? Toto pravidlo je aktivn Koment Agent pro lokln doruen Poloka "%s" nesm bt przdn
 Poloka "%s" je neplatn nebo nepln
Byt oekvn formt uivatel@domna
 Databze pro speciln smrovn Povoleno Pomoc [Pidej] lze pidat przdn dek pro alias Soubor /etc/sendmail.cf bude vygenerovn bez
podpory pro speciln (domnov) smrovn.
Systm sice obsahuje nkolik definic pro speciln
smrovn, ale tento konfiguran soubor je nebude vyuvat.
Povolenm "databze pro speciln smrovn"
v "zkladn informace" lze sjednat npravu
a pot znovu vygenerovat sendmail.cf. Virtuln e-mailov domna Virtuln domna (fqdn) Definice jedn virtuln domny Pomoc [Pidej] lze pidat novou virruln domnu Virtuln e-mailov domny Tato virtuln domna u je definovan  Zde lze definovat novou virtuln domnu pro e-mail.
Tento nov koncept nen pro vtinu konfigurac poteba.
 Nejsou definovan dn virtuln domny pro e-mail Vyberte domnu Virtuln e-mailov domny Aliasy pro tuto domnu Aliasy pro uivatele ve virtuln domn Soubory s aliasy pro domnu %s Tato virtuln domna m nkolik soubor s aliasy.
Vyberte jednu pro pravu Akceptovat e-mail pro %s Nelze vytvoit domnov jmno pro tento server.
Proto server nebude akceptovat e-mail sprvn.
Prosim, vlote plno domnov jmno v nastaven
"Zkladn informace o potai". V ppad nedoruitelnosti poslat na Toto pravidlo je aktivn Nov pravidlo pro makardu Pravidlo pro makardu %s Zde lze definovat pravidla, pomoc kterch se zprva z dan
domny nebo od danho uivatele transformuje tak, e pochz
z jin domny nebo od jinho uivatele. Pomoc [Pidej] lze definovat nov pravidlo pro makardu Pravidla pro makardu Lze nastavit vce pravidel pro makardu.
Klem je adresa pvodu, vetn uivatelskho jmna
 Pravidla pro makardu Neurit pesmrovn.
Nutno uvst uivatelsk et v poloce "pepsat na"
 Linuxconf odhadne Virtuln domna %s neexistuje Seznam virtuln domn pro e-mail na tomto serveru Virtuln domna pro e-mail Zmna vaeho hesla Pout UID vt ne Sprva virtuln domny Brna pro faxovn pes e-mail Brna pro faxovn pes e-mail je aktivn Pkaz pro zaazen do fronty Konfigurace brny pro faxovn pes e-mail Zde lze ovldat innost brny pro faxovn pes e-mail Jmno zny	Pedpona zny	Dlka	Pravidlo Pomoc [Pidej] se definuje nov faxov zna Faxov zny Zde lze specifikovat telefonn zny, kter
jsou k dispozici pro faxovn. Loggovac soubor Uivatel faxu Faxov zny Aliasy pro fax Tato obrazovka umouje konfigurovat innost brny,
tedy lze definovat, kdo, kde a jak me faxovat. Dlka telefonnho sla Uivatel, kte mohou faxovat Jedna faxov zna Zde lze specifikovat jednu faxovou znu Pedpona telefonn zny Smazat tento zznam Sprvce sluby Mail to Fax Spravovat brnu pro faxovn pes e-mail Pkaz pro zznam do logu Nedoruovat okamit Podpora pro falon e-mailov klienty (HELO) Zpracovat frontu kadch (minut) Seznam uivatel faxu Zde lze zadat seznam priviligovanch ivatel, kte
mohou faxovat vzdlen do nkterch telefonnch zn. Alias Pln jmno Telefonn slo Alias pro fax Zde se definuje e-mailov alias Alias
Jmno
Telefon
Pravidlo Seznam faxovch alias E-mailov adresa uivatele Uivatelsk jmno Veejn kl PGP (nepov) Uivatel faxu Zde se definuje jste minimln nastaven pro
faxovac konto pro privilegovanho uivatele
 PGP nepovinn Jedin lokln e-mail E-mail odkudkoliv Poadovat signaturu PGP Akceptovat jedin uivatele definovan pravidlem Akceptovat kadho uivatele faxu E-mail	Jmno Pstupov pravidlo Jedno pstupov pravidlo Pravidla pro faxovn Zde lze specifikovat pstupov pravidla pro rzn
faxov zny a aliasy Pstupov pravidla pro faxovn Jmno pravidla Zde lze definovat jedno pstupov pravidlo, kter bude
pouito pro omezen pstupu do zny a k aliasu Jmno zny Jmno pravidla	Pstup	Seznam uivatel Pomoc [Pidej] lze definovat nov pravidlo Ovldn pstupu Oven uivatele 1-Sluby Potovn systm Brna pro faxovn pes e-mail Virtuln e-mailov domny Dveryhodn uivatel Porovnvat pln uivatelsk jmna Soubory specifick rpo Sendmail Generuji %s
 Soubor %s nebyl vygenerovn Linuxconfem.
Bu ho Linuxconf nikdy negeneroval, nebo byl
run zmnen.

Linuxconf jej zazlohuje jako %s a pepe.

	V podku? Pozor Nepovedlo se tak, jak ekl administrtor
 Odmtat odeslatele Pedvn podle IP Pedvn podle jmna Pedvat potam Filtry proti spamu Pomoc [Pidej] lze pidat nov zznam Odeslatel zprvy Chybov zprva Odmtnut zprva Zde se zadva adresa odeslatele, kter
se m odfiltrovat.
Lze zadat plnou e-mailovou adresu, domnu,
jmno potae nebo IP adresu. Lze pedvat e-mail do Vlote seznam pota nebo st,
do kterch se m pota pedvat Jmno nebo IP adresa Odmtat e-mail z Kad zprva od nsledujcch osob nebo domn nebude
doruena.
 Odeslatel
Zprva Lze pedvat e-mail pro Toto je seznam pota a st, kter
mohou pouvat tento potae pro pedvn poty.
Lze je zadat bu plnou IP adreso potae, nebo
stenou IP adreso pro st. IP potae nebo st Tento seznam obsahuje potae a domny, kter
mohou pouvat tento pota pro pedvn e-mailu. Jmno potae nebo domny Zkladn Ovldn pedvn poty Seznam znmch spammer Povolit filtrovn pi pedvn (spam) Hlavn konfigurace poty Nasledujc konfigurace si neodpovdaj:
Jmno domny/potae %s nelze spravovat pomoc
 %s
i %s Implicitn pravidlo Linuxconfu Aliasy pro tento pota Nron ESMTP Alias pro e-mail alias pro virtuln domny nen pln Povolit tomuto potai/domn pouvat tento server(IP) Povolit tomuto potai/domn pouvat tento server Pedvat tomuto potai/sti Potovn systm (sendmail) Virtuln ty pro POP (jen e-mail) Pravidla pro virtuln domny Virtuln e-mailov domny Pout speciln interpret pkaz smrsh Interpret smrsh nen nainstalovn.
Generuji sendmail.cf s nastavenm /bin/sh Rzn Aliasy Maximln velikost UUCP zprvy e-mail Virtuln e-mailov domna %s
u je nastaven Je poteba virtuln e-mailov domny Mailconf: Virtuln e-mailov domna %s nen nastaven
 Mailconf: Virtuln e-mailov domna %s u je nastaven
 Neplatn pepna %s
 Modul mailconf

    --help
    --addvdom domna [--startuid uid ] [--daliases aliasy_domny ]
          [--faliase soubor_email_aliasy] [ --quota max_inbox_k] 
    --delvdom domna
 Pesmrovat zprvy na Neplatn znaky v aliasu Omezen velikost uivatelsk schrnky (k) Aliasy Match user full name the mail queue Manage Message ID Date sent Sender Size One message status This message is currently in sendmail queue.
You can delete from the queue if you want.
*** Are you really sure ? *** Mail queue This is the list in the queue.
You can review their status and erase them if need
right click on message to tag/untag it Id	Sender	Recipients	Date	Size to delete queued email messages Deleting mail message %s: size %d from %s
 Status Sent to Sent on %s
 Sent to %s
 Maximum recipients per msg. Defaults No limit Domain default Inbox max. size(k) Mail settings Privileges: Virtual email domains Useless alias: alias %s points to account %s Can't redirect emails to the same account
(Alias looping) Virtual email domain %s does not exist
 Manual User account %s does not exist in domain %s
 Filter program + args (opt) See virtual domains Aliases file %s does not exist
 Manage virtual email domains accounts Block open relay (ORDB) Base info Maximum number of users Emails Add more lines to enter email aliases Grow form Incoming mail are rejected Users can't retrieve their messages Lock domain Extra aliases files File path (absolute) Base info Locked Enable the VERIFY SMTP command Enable the EXPN SMTP command Delivery AUTH timeout (seconds) Disabled Enable the ETRN SMTP command Enable the VERB SMTP command Anyone may run mailq Anyone may run sendmail -q Return success DSNs21 Allow most SMTP status queries SMTP features Control Alias file %s Enter one email address per line You must specify the path
of the list file Builds server aliases from net interfaces Authentication warnings Add more lines to enter domain aliases Queue: Warn after Queue: Return after Setup your vacation message Sendmail setup You will be presented with a set of dialog to fully
configure a sendmail server. Your email address Your password Vacation text Vacation configuration  You must supply a complete email address
of the form user@some_domain.xxx Invalid email address or password Enable the vacation service Invalid email address Reset the correspondent list Vacation message updated.
 Database initialised, vacation service active.
 Vacation service disabled.
 Database cleared.
 Email user authentication Please identify yourself No changed performed You can turn the vacation mechanism on or off The vacation mechanism send one message per correspondent
The correspondent list is kept in a database
You may want to reset (empty) the database
if you change the message for example Enter the text to send to every correspondent while you are away Message subject user + domain: joe@some-domain.com Delete tagged Vacation settings Vacation message deleted.
 domain %s, user %s: Vacation message deleted: %s
 domain %s, user %s: Vacation message updated: %s
 Manage all virtual email domains domain %s, user %s: Vacation db initialised: %s
 domain %s, user %s: Vacation db deleted: %s
 domain %s, user %s: Vacation db reset: %s
 Manage virtual email domains aliases You are attempting to modify either
the filter program or the list file.
Only the superuser is allowed to do that.

You will be asked to supply the root password.
If you do not know it, cancel and revert your changes Administrator A pseudo-user admin@this-domain
may administer the vdomain.
It works only in WEB mode Enter the co-administrator password
or leave it blank to keep the previous one Co-administrator password (Re-enter password) Password differ, please re-enter You must supply a co-administrator password
to enable co-administration Enable co-administration %d correspondent(s) in list Edit list Vacation list Here is the email address list collected so far
by the vacation process. You have received at least
one message from those address since you have enabled
your vacation message. Listen on TCP port Listen on TCP address Changing ownership of mail file %s to %d from %d
 Now enter your new password twice
to make sure you typed it right New password New password (retype) Changing your password The two password are different.
Try again Change your password (Email users) Password changed Mail filters This is the list of currently configured
mail filters. Name	Socket	Flags A new mail filter mail filters Mail filter name Listen on port Flags One mail filter No spaces allowed in the alias name No spaces allowed in email addresses To	Rewritten to	Server	Priority	Active Priority Yes No 

==> linuxconf-1.34r3.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/mailconf-msg-1.34r3.cs <==
g  mailconf                 ,  :  N  T  g  z            $  H                -  K  b  r              	  	F  	U  	b  	q  	  	  	  	  	  
  
&  
9  
K  
X  
a  
{  
  
  
  
    &          (  3  ;  K  W  u        
  
  
  ?  I  W            ]  ~          4  T          8  l  {          A  Z    0  I  e       Z  q      3  E  d              1  <  Z            g  x            >  P  x              D  e  {            5  R  i            &  <  N  f            
  R  s          I  [  m  v              &               1   D   W   ~           !6  !N  !  !  !  !  "  "   "  "  #A  #\  #e  #~  #  #  #  $:  $Y  $r  $  $  $  $  %%  %C  %^  %  %  %  %  &1  &7  &>  &]  &d  &  &  &  ')  '?  '  (  (#  (M  (T  (i  (x  (  (  (  (  (  (  ))  )4  )  )  )  *  *  *&  *2  *>  *Z  *c  *l  *{  *  *  *  *  +%  +M  +T  +  +  +  +  +  ,  ,  ,1  ,8  ,^  ,h  ,  ,  ,  ,  ,  ,  ,  -  -)  -2  -I  -R  -o  -  -  -  -  -  -  .  .  .6  .a  .  .  .  .  .  /  /  /l  /  /  /  /  /  /  0  0&  0;  0Q  0W  0n  0  0  0  0  1  1  10  1^  2  2W  2g  2  2  2  2  2  3)  3J  3{  3  3  3  4  4  55  5  5  5  5  6  6"  64  6P  6Z  6h  7  7,  7B  7t  7  7  7  7  8  8=  8N  8[  8  8  8  8  8  8  8  8  9  9B  9i  9r  9v  9y  9%s neexistuje %s nen spustiteln alias Filtrovac program Soubor se seznamem Definice jednoho aliasu Pomoc [Pidej] lze zskat msto pro dal
mailing list
 prava aliasu Nutno zadat jmno Vechny poloky jsou przdn Duplikace aliasu, odmtnuto prava globlnch alias pro e-mail Zde lze upravovat/pidvat/mazat
aliasy pro e-mail, kter palt pro cel systm Pomoc [Add] lze pidato nov alias Zpis %s Aliasy pro domny Aliasy pro tento pota Prezentovat tento pota jako E-mail server E-mailov brna Protokol pro e-mailovou brnu Vylepen SMTP (ESMTP) Standardn SMTP Doporuen modern UUCP Star UUCP Vlastnosti UUCP mail nespracovvt v dvkch Omezen velikosti zprvy Doruovat lokln pro uivatele Nepouvat makardu pro uivatele Formt databze pro speciln smrovn Vlastnosti DNS ekat na DNS Nepouvat DNS Omezit DNS len na domny Zkladn nastaven sendmailu Nastavit sendmail %s byl pegenerovn! Zkladn informace Speciln smrovn (pro domny) Komplexn smrovn (pro uivatele) Uivatelsk aliasy Testovac ppady Konfigurovat Nastavit Konfigurtor pro sendmail Tato obrazovka umouje konfigurovat
Sendmail, program pro penos elektronick poty
 Cl Pesmrovn Spravovat subdomny stejn Program pro posln Speciln smrovn Vlote clov pota, pota
pes kter se m pota pesmrovat
a program, kter zajist penos (mailer) Nutno vyplnit vechny poloky Seeciln smrovn Zde lze upravovat/pidvat/mazat smrovn
 Pomoc [Pidej] lze pidat specifikaci jednoho smrovn Odeslatel Adrest Nov odeslatel Pepsno na Pesmrovat na server (nepov) Pomoc [Sma] lze smazat tento zznam Nov komplexn smrovn Komplexn smrovn pro %s Zde lze nastavit zachytvn e-mail
a jejich pesmrovn na jin e-mailov server,
ppadn za pouit jinho protokolu.
Je mon pepisovat adresu adresta,
ppadn i odeslatele
 Pomoc [Pidej] lze pidat pravidlo pro komplexn smrovn Komplexn smrovn Zde lze nastavit rzn komplexn smrovn e-mail
Klem je clov adresa, vetn uivatelskho jmna
 Generovat Generovn %s Zmnilo se nastaven sendmailu.
Mus bt vygenerovn nov soubor %s.
M se tak stt okamit? Toto pravidlo je aktivn Koment Agent pro lokln doruen Poloka "%s" nesm bt przdn
 Poloka "%s" je neplatn nebo nepln
Byt oekvn formt uivatel@domna
 Databze pro speciln smrovn Povoleno Pomoc [Pidej] lze pidat przdn dek pro alias Soubor /etc/sendmail.cf bude vygenerovn bez
podpory pro speciln (domnov) smrovn.
Systm sice obsahuje nkolik definic pro speciln
smrovn, ale tento konfiguran soubor je nebude vyuvat.
Povolenm "databze pro speciln smrovn"
v "zkladn informace" lze sjednat npravu
a pot znovu vygenerovat sendmail.cf. Virtuln e-mailov domna Virtuln domna (fqdn) Definice jedn virtuln domny Pomoc [Pidej] lze pidat novou virruln domnu Virtuln e-mailov domny Tato virtuln domna u je definovan  Zde lze definovat novou virtuln domnu pro e-mail.
Tento nov koncept nen pro vtinu konfigurac poteba.
 Nejsou definovan dn virtuln domny pro e-mail Vyberte domnu Virtuln e-mailov domny Aliasy pro tuto domnu Aliasy pro uivatele ve virtuln domn Soubory s aliasy pro domnu %s Tato virtuln domna m nkolik soubor s aliasy.
Vyberte jednu pro pravu Akceptovat e-mail pro %s Nelze vytvoit domnov jmno pro tento server.
Proto server nebude akceptovat e-mail sprvn.
Prosim, vlote plno domnov jmno v nastaven
"Zkladn informace o potai". V ppad nedoruitelnosti poslat na Toto pravidlo je aktivn Nov pravidlo pro makardu Pravidlo pro makardu %s Zde lze definovat pravidla, pomoc kterch se zprva z dan
domny nebo od danho uivatele transformuje tak, e pochz
z jin domny nebo od jinho uivatele. Pomoc [Pidej] lze definovat nov pravidlo pro makardu Pravidla pro makardu Lze nastavit vce pravidel pro makardu.
Klem je adresa pvodu, vetn uivatelskho jmna
 Pravidla pro makardu Neurit pesmrovn.
Nutno uvst uivatelsk et v poloce "pepsat na"
 Linuxconf odhadne Virtuln domna %s neexistuje Seznam virtuln domn pro e-mail na tomto serveru Virtuln domna pro e-mail Zmna vaeho hesla Pout UID vt ne Sprva virtuln domny Brna pro faxovn pes e-mail Brna pro faxovn pes e-mail je aktivn Pkaz pro zaazen do fronty Konfigurace brny pro faxovn pes e-mail Zde lze ovldat innost brny pro faxovn pes e-mail Jmno zny	Pedpona zny	Dlka	Pravidlo Pomoc [Pidej] se definuje nov faxov zna Faxov zny Zde lze specifikovat telefonn zny, kter
jsou k dispozici pro faxovn. Loggovac soubor Uivatel faxu Faxov zny Aliasy pro fax Tato obrazovka umouje konfigurovat innost brny,
tedy lze definovat, kdo, kde a jak me faxovat. Dlka telefonnho sla Uivatel, kte mohou faxovat Jedna faxov zna Zde lze specifikovat jednu faxovou znu Pedpona telefonn zny Smazat tento zznam Sprvce sluby Mail to Fax Spravovat brnu pro faxovn pes e-mail Pkaz pro zznam do logu Nedoruovat okamit Podpora pro falon e-mailov klienty (HELO) Zpracovat frontu kadch (minut) Seznam uivatel faxu Zde lze zadat seznam priviligovanch ivatel, kte
mohou faxovat vzdlen do nkterch telefonnch zn. Alias Pln jmno Telefonn slo Alias pro fax Zde se definuje e-mailov alias Alias
Jmno
Telefon
Pravidlo Seznam faxovch alias E-mailov adresa uivatele Uivatelsk jmno Veejn kl PGP (nepov) Uivatel faxu Zde se definuje jste minimln nastaven pro
faxovac konto pro privilegovanho uivatele
 PGP nepovinn Jedin lokln e-mail E-mail odkudkoliv Poadovat signaturu PGP Akceptovat jedin uivatele definovan pravidlem Akceptovat kadho uivatele faxu E-mail	Jmno Pstupov pravidlo Jedno pstupov pravidlo Pravidla pro faxovn Zde lze specifikovat pstupov pravidla pro rzn
faxov zny a aliasy Pstupov pravidla pro faxovn Jmno pravidla Zde lze definovat jedno pstupov pravidlo, kter bude
pouito pro omezen pstupu do zny a k aliasu Jmno zny Jmno pravidla	Pstup	Seznam uivatel Pomoc [Pidej] lze definovat nov pravidlo Ovldn pstupu Oven uivatele 1-Sluby Potovn systm Brna pro faxovn pes e-mail Virtuln e-mailov domny Dveryhodn uivatel Porovnvat pln uivatelsk jmna Soubory specifick rpo Sendmail Generuji %s
 Soubor %s nebyl vygenerovn Linuxconfem.
Bu ho Linuxconf nikdy negeneroval, nebo byl
run zmnen.

Linuxconf jej zazlohuje jako %s a pepe.

	V podku? Pozor Nepovedlo se tak, jak ekl administrtor
 Odmtat odeslatele Pedvn podle IP Pedvn podle jmna Pedvat potam Filtry proti spamu Pomoc [Pidej] lze pidat nov zznam Odeslatel zprvy Chybov zprva Odmtnut zprva Zde se zadva adresa odeslatele, kter
se m odfiltrovat.
Lze zadat plnou e-mailovou adresu, domnu,
jmno potae nebo IP adresu. Lze pedvat e-mail do Vlote seznam pota nebo st,
do kterch se m pota pedvat Jmno nebo IP adresa Odmtat e-mail z Kad zprva od nsledujcch osob nebo domn nebude
doruena.
 Odeslatel
Zprva Lze pedvat e-mail pro Toto je seznam pota a st, kter
mohou pouvat tento potae pro pedvn poty.
Lze je zadat bu plnou IP adreso potae, nebo
stenou IP adreso pro st. IP potae nebo st Tento seznam obsahuje potae a domny, kter
mohou pouvat tento pota pro pedvn e-mailu. Jmno potae nebo domny Zkladn Ovldn pedvn poty Seznam znmch spammer Povolit filtrovn pi pedvn (spam) Hlavn konfigurace poty Nasledujc konfigurace si neodpovdaj:
Jmno domny/potae %s nelze spravovat pomoc
 %s
i %s Implicitn pravidlo Linuxconfu Aliasy pro tento pota Nron ESMTP Alias pro e-mail alias pro virtuln domny nen pln Povolit tomuto potai/domn pouvat tento server(IP) Povolit tomuto potai/domn pouvat tento server Pedvat tomuto potai/sti Potovn systm (sendmail) Virtuln ty pro POP (jen e-mail) Pravidla pro virtuln domny Virtuln e-mailov domny Pout speciln interpret pkaz smrsh Interpret smrsh nen nainstalovn.
Generuji sendmail.cf s nastavenm /bin/sh Rzn Aliasy Maximln velikost UUCP zprvy e-mail Virtuln e-mailov domna %s
u je nastaven Je poteba virtuln e-mailov domny Mailconf: Virtuln e-mailov domna %s nen nastaven
 Mailconf: Virtuln e-mailov domna %s u je nastaven
 Neplatn pepna %s
 Modul mailconf

    --help
    --addvdom domna [--startuid uid ] [--daliases aliasy_domny ]
          [--faliase soubor_email_aliasy] [ --quota max_inbox_k] 
    --delvdom domna
 Pesmrovat zprvy na Neplatn znaky v aliasu Omezen velikost uivatelsk schrnky (k) Aliasy Match user full name the mail queue Manage Message ID Date sent Sender Size One message status This message is currently in sendmail queue.
You can delete from the queue if you want.
*** Are you really sure ? *** Mail queue This is the list in the queue.
You can review their status and erase them if need
right click on message to tag/untag it Id	Sender	Recipients	Date	Size to delete queued email messages Deleting mail message %s: size %d from %s
 Status Sent to Sent on %s
 Sent to %s
 Maximum recipients per msg. Defaults No limit Domain default Inbox max. size(k) Mail settings Privileges: Virtual email domains Useless alias: alias %s points to account %s Can't redirect emails to the same account
(Alias looping) Virtual email domain %s does not exist
 Manual User account %s does not exist in domain %s
 Filter program + args (opt) See virtual domains Aliases file %s does not exist
 Manage virtual email domains accounts Block open relay (ORDB) Base info Maximum number of users Emails Add more lines to enter email aliases Grow form Incoming mail are rejected Users can't retrieve their messages Lock domain Extra aliases files File path (absolute) Base info Locked Enable the VERIFY SMTP command Enable the EXPN SMTP command Delivery AUTH timeout (seconds) Disabled Enable the ETRN SMTP command Enable the VERB SMTP command Anyone may run mailq Anyone may run sendmail -q Return success DSNs21 Allow most SMTP status queries SMTP features Control Alias file %s Enter one email address per line You must specify the path
of the list file Builds server aliases from net interfaces Authentication warnings Add more lines to enter domain aliases Queue: Warn after Queue: Return after Setup your vacation message Sendmail setup You will be presented with a set of dialog to fully
configure a sendmail server. Your email address Your password Vacation text Vacation configuration  You must supply a complete email address
of the form user@some_domain.xxx Invalid email address or password Enable the vacation service Invalid email address Reset the correspondent list Vacation message updated.
 Database initialised, vacation service active.
 Vacation service disabled.
 Database cleared.
 Email user authentication Please identify yourself No changed performed You can turn the vacation mechanism on or off The vacation mechanism send one message per correspondent
The correspondent list is kept in a database
You may want to reset (empty) the database
if you change the message for example Enter the text to send to every correspondent while you are away Message subject user + domain: joe@some-domain.com Delete tagged Vacation settings Vacation message deleted.
 domain %s, user %s: Vacation message deleted: %s
 domain %s, user %s: Vacation message updated: %s
 Manage all virtual email domains domain %s, user %s: Vacation db initialised: %s
 domain %s, user %s: Vacation db deleted: %s
 domain %s, user %s: Vacation db reset: %s
 Manage virtual email domains aliases You are attempting to modify either
the filter program or the list file.
Only the superuser is allowed to do that.

You will be asked to supply the root password.
If you do not know it, cancel and revert your changes Administrator A pseudo-user admin@this-domain
may administer the vdomain.
It works only in WEB mode Enter the co-administrator password
or leave it blank to keep the previous one Co-administrator password (Re-enter password) Password differ, please re-enter You must supply a co-administrator password
to enable co-administration Enable co-administration %d correspondent(s) in list Edit list Vacation list Here is the email address list collected so far
by the vacation process. You have received at least
one message from those address since you have enabled
your vacation message. Listen on TCP port Listen on TCP address Changing ownership of mail file %s to %d from %d
 Now enter your new password twice
to make sure you typed it right New password New password (retype) Changing your password The two password are different.
Try again Change your password (Email users) Password changed Mail filters This is the list of currently configured
mail filters. Name	Socket	Flags A new mail filter mail filters Mail filter name Listen on port Flags One mail filter No spaces allowed in the alias name No spaces allowed in email addresses To	Rewritten to	Server	Priority	Active Priority Yes No Double bounce dest. to /dev/null 
